@@ -22,16 +22,20 @@ def transpile_function(function: str) -> str:
 	}, f'{function}(')
 
 
-def transpile_word(word: str) -> str:
+def transpile_word(word: str, translated: str) -> str:
 	translations = {
 		'body': 'request.json',
 		'form': 'request.form',
 		'args': 'request.args',
+		'files': 'request.files',
 		'req': 'AskLibrary.get_all_req()',
 		'datetime': 'datetime.datetime',
 		'respond': 'return'
 	}
 
+	if word in translations and translated and translated[-1] in ['.']:
+		return word
+
 	return generic_transpile_symbol(word, translations)
 
 
